==> kdesvn_1.0.4.orig.tar.gz: kdesvn-1.0.4/src/ksvnwidgets/depthselector.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Rajko Albrecht  ral@alwins-world.de             *
 *   http://kdesvn.alwins-world.de/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef DEPTHSELECTOR_H
#define DEPTHSELECTOR_H

#include "src/ksvnwidgets/depthform.h"

#include "src/svnqt/svnqttypes.hpp"

class QCheckBox;

class DepthSelector: public DepthSettings {
    Q_OBJECT
public:
    DepthSelector(QWidget *parent = 0, const char *name = 0);
    virtual ~DepthSelector();
    svn::Depth getDepth()const;
    void addItemWidget(QWidget*);
    void hideDepth(bool hide);

protected:
    QCheckBox*m_recurse;
};

#endif

==> kdesvn_1.2.1.orig.tar.gz: kdesvn-1.2.1/src/ksvnwidgets/depthselector.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Rajko Albrecht  ral@alwins-world.de             *
 *   http://kdesvn.alwins-world.de/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef DEPTHSELECTOR_H
#define DEPTHSELECTOR_H

#include "src/ksvnwidgets/ui_depthform.h"

#include "src/svnqt/svnqttypes.hpp"

class QCheckBox;

class DepthSelector: public QWidget, Ui::DepthForm {
    Q_OBJECT
public:
    DepthSelector(QWidget *parent = 0);
    virtual ~DepthSelector();
    svn::Depth getDepth()const;
    void addItemWidget(QWidget*);
    void hideDepth(bool hide);

protected:
    QCheckBox*m_recurse;
};

#endif
